==> nocc-1.8.1.tbz: www/nocc/lang/tl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: tl.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Tagalog (Tagalog)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author AnakngAraw
 */

$lang_locale = 'tl.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Walang laman ang hanay ng lagdaang papasok';
$err_passwd_empty = 'Walang laman ang hanay ng hudyat';
$alt_delete = 'Burahin ang napiling mga mensahe';
$alt_delete_one = 'Burahin ang mensahe';
$alt_new_msg = 'Bagong mga mensahe';
$alt_reply = 'Tumugon sa may-akda';
$alt_reply_all = 'Tuguning lahat';
$alt_forward = 'Isulong';
$alt_next = 'Susunod';
$alt_prev = 'Sinundan';
$title_next_page = 'Susunod na pahina';
$title_prev_page = 'Sinundang pahina';
$title_next_msg = 'Susunod na mensahe';
$title_prev_msg = 'Sinundang mensahe';
$html_on = 'nasa ibabaw ng';
$html_theme_label = 'Paksang-diwa';
$html_welcome = 'Maligayang pagdating sa %1$s';
$html_login = 'Lumagdang papasok';
$html_passwd = 'Salitang-hudyat';
$html_submit = 'Ipasa';
$html_help = 'Tulong';
$html_server = 'Tagapaghain';
$html_wrong = 'Hindi tama ang lagdang papasok o ang salitang-hudyat';
$html_retry = 'Subuking muli';
$html_remember = 'Tandaan ang mga pagtatakda';
$html_msgperpage_label = 'Mga mensahe sa bawat isang pahina';
$html_preferences = 'Mga nais';
$html_full_name_label = 'Buong pangalan';
$html_email_address_label = 'Adres ng E-liham';
$html_ccself = 'Kk sarili';
$html_hide_addresses = 'Ikubli ang mga adres';
$html_outlook_quoting = 'Pagsiping may estilong Outlook';
$html_reply_to = 'Tumugon kay';
$html_use_signature = 'Gamitin ang lagda';
$html_signature = 'Lagda';
$html_reply_leadin_label = 'Pambungad na Tugon';
$html_prefs_updated = 'Isinapanahon ang mga nais';
$html_manage_folders_link = 'Pamahalaan ang mga Nakaluping Polyeto ng IMAP';
$html_manage_filters_link = 'Pamahalaan ang mga Pansala ng e-Liham';
$html_use_graphical_smilies = 'Gamitin ang nakalarawang mga taga-ngiti';
$html_sent_folder_label = 'Sipiin ang ipinadalang mga liham papaloob sa isang nakalaang nakaluping polyeto';
$html_trash_folder_label = 'Ilipat ang binurang mga liham papaloob sa isang nakalaang polyetong nakalupi';
$html_colored_quotes = 'Kinulayang mga sipi';
$html_display_struct = 'Ipakita ang may kayariang teksto';
$html_send_html_mail = 'Ipadala ang liham na nasa anyong HTML';
$html_folders = 'Mga polyetong nakalupi';
$html_folders_create_failed = 'Hindi malilikha ang polyetong nakalupi!';
$html_folders_sub_failed = 'Hindi magawang makatanggap mula polyetong nakalupi!';
$html_folders_unsub_failed = 'Hindi magawang tanggalin ang pagtanggap mula sa polyetong nakalupi!';
$html_folders_rename_failed = 'Hindi mapangalanang muli ang polyetong nakalupi!';
$html_folders_updated = 'Naisapanahon na ang mga polyetong nakalupi';
$html_folder_subscribe = 'Tumanggap mula sa';
$html_folder_rename = 'Muling pangalanan';
$html_folder_create = 'Lumikha ng bagong nakaluping polyetong may pangalang';
$html_folder_remove = 'Huwag nang tumanggap mula sa';
$html_folder_delete = 'Burahin';
$html_folder_to = 'na';
$html_filter_remove = 'Burahin';
$html_filter_body = 'Katawan ng Mensahe';
$html_filter_subject = 'Paksa ng Mensahe';
$html_filter_to = 'Papunta sa Hanay';
$html_filter_cc = 'Kk Hanay';
$html_filter_from = 'Mula sa Hanay';
$html_filter_change_tip = 'Upang baguhin ang isang pansala patungan lamang ito.';
$html_reapply_filters = 'Muling gamitin ang lahat ng mga pansala';
$html_filter_contains = 'naglalaman ng';
$html_filter_name = 'Pangalan ng Pansala';
$html_filter_action = 'Galaw ng Pansala';
$html_filter_moveto = 'Ilipat sa';
$html_select_one = '--Pumili ng Isa--';
$html_and = 'At';
$html_new_msg_in = 'Mga bagong mensaheng nasa loob ng';
$html_or = 'o';
$html_move = 'Ilipat';
$html_copy = 'Sipiin';
$html_messages_to = 'piniling mga mensaheng';
$html_gotopage = 'Pumunta sa Pahina';
$html_gotofolder = 'Pumunta sa Polyetong Nakalupi';
$html_other_folders = 'Talaan ng Polyetong Nakalupi';
$html_page = 'Pahina';
$html_of = 'ng';
$html_view_header = 'Tingnan ang pa-ulo';
$html_remove_header = 'Ikubli ang pa-ulo';
$html_inbox = 'Kahon ng pumapasok';
$html_new_msg = 'Isulat';
$html_reply = 'Tumugon';
$html_reply_short = 'Hinggil sa';
$html_reply_all = 'Tuguning lahat';
$html_forward = 'Isulong';
$html_forward_short = 'Sulong';
$html_forward_info = 'Ang pinasulong na mensahe ay ipapadala bilang isang kalakip sa isang ito.';
$html_delete = 'Burahin';
$html_new = 'Bago';
$html_mark = 'Burahin';
$html_att_label = 'Kalakip';
$html_atts_label = 'Mga kalakip';
$html_att_unknown = '[hindi alam]';
$html_attach = 'Ilakip';
$html_attach_forget = 'Dapat mong ilakip ang iyong mga talaksan bago mo ipadala ang iyong mensahe!';
$html_attach_delete = 'Pinili ang Pagtanggal';
$html_attach_none = 'Dapat kang pumili ng isang talaksang ilalakip!';
$html_sort_by = 'Pagsama-samahin ayon sa';
$html_sort = 'Pagsama-samahin';
$html_from = 'Mula sa';
$html_subject = 'Paksa';
$html_date = 'Petsa';
$html_sent = 'Ipadala';
$html_wrote = 'isinulat';
$html_size = 'Sukat';
$html_totalsize = 'Kabuoang Sukat';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'mga bayt';
$html_filename = 'Pangalan ng talaksan';
$html_to = 'Para kay';
$html_cc = 'Kk';
$html_bcc_label = 'Bkk';
$html_nosubject = 'Walang paksa';
$html_send = 'Ipadala';
$html_cancel = 'Huwag ituloy';
$html_no_mail = 'Walang mensahe.';
$html_logout = 'Umalis sa pagkakalagda';
$html_msg = 'Mensahe';
$html_msgs = 'Mga mensahe';
$html_configuration = 'Hindi maayos ang pagkakahanda ng tagapaghaing ito!';
$html_priority_label = 'Dapat mauna';
$html_lowest = 'Pinakamababa';
$html_low = 'Mababa';
$html_normal = 'Karaniwan';
$html_high = 'Mataas';
$html_highest = 'Pinakamataas';
$html_receipt = 'Humiling ng isang resibong bumabalik';
$html_select = 'Piliin';
$html_select_all = 'Baligtarin ang Pilian';
$html_loading_image = 'Ikinakarga ang larawan';
$html_send_confirmed = 'Tinanggap na ang liham mo upang maipadala';
$html_no_sendaction = 'Walang tinukoy na galaw. Subuking paganahin ang JavaScript.';
$html_error_occurred = 'Naganap ang isang kamalian';
$html_prefs_file_error = 'Hindi nagawang buksan ang talaksan ng mga nais para sa pagsusulat.';
$html_wrap = 'Balutin ang palabas na mga mensahe sa:';
$html_wrap_none = 'Wala';
$html_usenet_separator = 'Panghiwalay ng \'\'usenet\'\' ("-- \n") bago ang lagda';
$html_mark_as = 'Tatakan bilang';
$html_read = 'basahin';
$html_unread = 'huwag basahin';
$html_encoding_label = 'Pagkokodigo ng panitik';
$html_add = 'Idagdag';
$html_contacts = '%1$s Mga kaugnayan';
$html_modify = 'Baguhin';
$html_back = 'Bumalik';
$html_contact_add = 'Magdagdag ng bagong kaugnayan';
$html_contact_mod = 'Baguhin ang isang kaugnayan';
$html_contact_first = 'Unang pangalan';
$html_contact_last = 'Apelyido';
$html_contact_nick = 'Palayaw';
$html_contact_mail = 'Liham';
$html_contact_list = 'Talaan ng kaugnayan ni %1$s';
$html_contact_del = 'mula sa talaan ng mga kaugnayan';
$html_contact_err1 = 'Ang pinakamataas na bilang ng mga kaugnayan ay';
$html_contact_err2 = 'Hindi ka makapagdaragdag ng isang bagong kaugnayan';
$html_contact_err3 = 'Wala kang mga karapatan upang makapunta sa talaan ng mga kaugnayan';
$html_del_msg = 'Burahin ang napiling mga mensahe?';
$html_down_mail = 'Ikargang pababa';
$original_msg = '-- Orihinal na Mensahe --';
$to_empty = 'Hindi dapat na walang lamang ang hanay ng \'Para kay\'!';
$html_images_warning = 'Para sa iyong kaligtasan, hindi ipinapakita ang malalayong mga larawan.';
$html_images_display = 'Ipakita ang mga larawan';
$html_smtp_error_no_conn = 'Hindi nagawang buksan ang ugnayang SMTP.';
$html_smtp_error_unexpected = 'Hindi inaasahang tugon ng SMTP:';
$lang_could_not_connect = 'Hindi makaugnay sa tagapaghain';
$lang_invalid_msg_num = 'Masamang bilang ng mensahe';
$html_file_upload_attack = 'Maaaring paglusob sa ikinakargang talaksan';
$html_invalid_email_address = 'Hindi tanggap na adres ng e-liham';
$html_invalid_msg_per_page = 'Hindi tanggap na bilang ng mga mensahe sa bawat isang pahina';
$html_invalid_wrap_msg = 'Hindi tanggap na lapad ng balot ng mensahe';
$html_seperate_msg_win = 'Mga mensaheng nasa loob ng nakahiwalay na bintana';
$html_err_file_contacts = 'Hindi nagawang buksan ang talaksan ng mga kaugnayan para sa pagsusulat.';
$html_session_file_error = 'Hindi nagawang buksan ang talaksan ng panahong inilaan para sa pagsusulat.';
$html_login_not_allowed = 'Hindi pinapahintulutan ang ganitong paglagdang papasok para sa pag-ugnay.';
$lang_err_send_delay = 'Dapat kang maghintay sa pagitan ng dalawang mga liham (%1$d mga segundo)';
$html_search = 'Hanapin';

==> nocc-1.8.3.tbz: www/nocc/lang/tl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: tl.php 2199 2010-06-03 23:40:34Z siebrand $
 */

/** Tagalog (Tagalog)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author AnakngAraw
 */

$lang_locale = 'tl.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Walang laman ang hanay ng lagdaang papasok';
$err_passwd_empty = 'Walang laman ang hanay ng hudyat';
$alt_delete = 'Burahin ang napiling mga mensahe';
$alt_delete_one = 'Burahin ang mensahe';
$alt_new_msg = 'Bagong mga mensahe';
$alt_reply = 'Tumugon sa may-akda';
$alt_reply_all = 'Tuguning lahat';
$alt_forward = 'Isulong';
$alt_next = 'Susunod';
$alt_prev = 'Sinundan';
$title_next_page = 'Susunod na pahina';
$title_prev_page = 'Sinundang pahina';
$title_next_msg = 'Susunod na mensahe';
$title_prev_msg = 'Sinundang mensahe';
$html_theme_label = 'Tema:';
$html_welcome = 'Maligayang pagdating sa %1$s';
$html_login = 'Lumagda';
$html_user_label = 'Tagagamit:';
$html_passwd_label = 'Hudyat:';
$html_submit = 'Ipasa';
$html_help = 'Tulong';
$html_server_label = 'Tagapaghain:';
$html_wrong = 'Hindi tama ang lagdang papasok o ang salitang-hudyat';
$html_retry = 'Subuking muli';
$html_remember = 'Tandaan ang mga pagtatakda';
$html_lang_label = 'Wika:';
$html_msgperpage_label = 'Mga mensahe sa bawat pahina:';
$html_preferences = 'Mga nais';
$html_full_name_label = 'Buong pangalan:';
$html_email_address_label = 'Adres ng e-liham:';
$html_ccself = 'Kk sarili';
$html_hide_addresses = 'Ikubli ang mga adres';
$html_outlook_quoting = 'Pagsiping may estilong Outlook';
$html_reply_to = 'Tumugon kay';
$html_use_signature = 'Gamitin ang lagda';
$html_signature = 'Lagda';
$html_signature_label = 'Lagda:';
$html_reply_leadin_label = 'Pambungad ng Tugon:';
$html_prefs_updated = 'Isinapanahon ang mga nais';
$html_manage_folders_link = 'Pamahalaan ang mga Nakaluping Polyeto ng IMAP';
$html_manage_filters_link = 'Pamahalaan ang mga Pansala ng e-Liham';
$html_use_graphical_smilies = 'Gamitin ang nakalarawang mga taga-ngiti';
$html_sent_folder_label = 'Sipiin ang ipinadalang mga e-liham papaloob sa isang nakalaang nakaluping polyeto:';
$html_trash_folder_label = 'Ilipat ang binurang mga e-liham papaloob sa isang nakalaang polyetong nakalupi:';
$html_colored_quotes = 'Kinulayang mga sipi';
$html_display_struct = 'Ipakita ang may kayariang teksto';
$html_send_html_mail = 'Ipadala ang liham na nasa anyong HTML';
$html_folders = 'Mga polyetong nakalupi';
$html_folders_create_failed = 'Hindi malilikha ang polyetong nakalupi!';
$html_folders_sub_failed = 'Hindi magawang makatanggap mula polyetong nakalupi!';
$html_folders_unsub_failed = 'Hindi magawang tanggalin ang pagtanggap mula sa polyetong nakalupi!';
$html_folders_rename_failed = 'Hindi mapangalanang muli ang polyetong nakalupi!';
$html_folders_updated = 'Naisapanahon na ang mga polyetong nakalupi';
$html_folder_subscribe = 'Tumanggap mula sa';
$html_folder_rename = 'Muling pangalanan';
$html_folder_create = 'Lumikha ng bagong nakaluping polyetong may pangalang';
$html_folder_remove = 'Huwag nang tumanggap mula sa';
$html_folder_delete = 'Burahin';
$html_folder_to = 'na';
$html_filter_remove = 'Burahin';
$html_filter_body = 'Katawan ng Mensahe';
$html_filter_subject = 'Paksa ng Mensahe';
$html_filter_to = 'Papunta sa Hanay';
$html_filter_cc = 'Kk Hanay';
$html_filter_from = 'Mula sa Hanay';
$html_filter_change_tip = 'Upang baguhin ang isang pansala patungan lamang ito.';
$html_reapply_filters = 'Muling gamitin ang lahat ng mga pansala';
$html_filter_contains = 'naglalaman ng';
$html_filter_name = 'Pangalan ng Pansala';
$html_filter_action = 'Galaw ng Pansala';
$html_filter_moveto = 'Ilipat sa';
$html_select_one = '--Pumili ng Isa--';
$html_and = 'At';
$html_new_msg_in = 'Mga bagong mensaheng nasa loob ng';
$html_or = 'o';
$html_move = 'Ilipat';
$html_copy = 'Sipiin';
$html_messages_to = 'piniling mga mensaheng';
$html_gotopage = 'Pumunta sa Pahina';
$html_gotofolder = 'Pumunta sa Polyetong Nakalupi';
$html_other_folders = 'Talaan ng Polyetong Nakalupi';
$html_page = 'Pahina';
$html_of = 'ng';
$html_view_header = 'Tingnan ang pa-ulo';
$html_remove_header = 'Ikubli ang pa-ulo';
$html_inbox = 'Kahon ng pumapasok';
$html_new_msg = 'Isulat';
$html_reply = 'Tumugon';
$html_reply_short = 'Hinggil sa:';
$html_reply_all = 'Tuguning lahat';
$html_forward = 'Isulong';
$html_forward_short = 'Sulong:';
$html_forward_info = 'Ang pinasulong na mensahe ay ipapadala bilang isang kalakip sa isang ito.';
$html_delete = 'Burahin';
$html_new = 'Bago';
$html_mark = 'Burahin';
$html_att_label = 'Kalakip:';
$html_atts_label = 'Mga kalakip:';
$html_unknown = '[hindi alam]';
$html_attach = 'Ilakip';
$html_attach_forget = 'Dapat mong ilakip ang iyong mga talaksan bago mo ipadala ang iyong mensahe!';
$html_attach_delete = 'Pinili ang Pagtanggal';
$html_attach_none = 'Dapat kang pumili ng isang talaksang ilalakip!';
$html_sort_by = 'Pagsama-samahin ayon sa';
$html_sort = 'Pagsama-samahin';
$html_from = 'Mula sa';
$html_from_label = 'Mula kay:';
$html_subject = 'Paksa';
$html_subject_label = 'Paksa:';
$html_date = 'Petsa';
$html_date_label = 'Petsa:';
$html_sent_label = 'Ipadala:';
$html_wrote = 'isinulat';
$html_size = 'Sukat';
$html_totalsize = 'Kabuoang Sukat';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'mga bayt';
$html_filename = 'Pangalan ng talaksan';
$html_to = 'Para kay';
$html_to_label = 'Para kay:';
$html_cc = 'Kk';
$html_cc_label = 'May kopya:';
$html_bcc_label = 'Iba pang may kopya ngunit nakakubli:';
$html_nosubject = 'Walang paksa';
$html_send = 'Ipadala';
$html_cancel = 'Huwag ituloy';
$html_no_mail = 'Walang mensahe.';
$html_logout = 'Umalis sa pagkakalagda';
$html_msg = 'Mensahe';
$html_msgs = 'Mga mensahe';
$html_configuration = 'Hindi maayos ang pagkakahanda ng tagapaghaing ito!';
$html_priority = 'Dapat mauna';
$html_priority_label = 'Dapat mauna:';
$html_lowest = 'Pinakamababa';
$html_low = 'Mababa';
$html_normal = 'Karaniwan';
$html_high = 'Mataas';
$html_highest = 'Pinakamataas';
$html_flagged = 'Ibinandila';
$html_spam = 'Ispam';
$html_spam_warning = 'Nauri ang mensaheng ito bilang ispam.';
$html_receipt = 'Humiling ng isang resibong bumabalik';
$html_select = 'Piliin';
$html_select_all = 'Baligtarin ang Pilian';
$html_select_contacts = 'Piliin ang mga kakapag-ugnayanin';
$html_loading_image = 'Ikinakarga ang larawan';
$html_send_confirmed = 'Tinanggap na ang liham mo upang maipadala';
$html_no_sendaction = 'Walang tinukoy na galaw. Subuking paganahin ang JavaScript.';
$html_error_occurred = 'Naganap ang isang kamalian';
$html_prefs_file_error = 'Hindi nagawang buksan ang talaksan ng mga nais para sa pagsusulat.';
$html_wrap = 'Bilang ng mga panitik na babaluting palabas na mga mensahe papunta sa:';
$html_wrap_none = 'Walang balot';
$html_usenet_separator = 'Panghiwalay ng \'\'usenet\'\' ("-- \n") bago ang lagda';
$html_mark_as = 'Tatakan bilang';
$html_read = 'basahin';
$html_unread = 'huwag basahin';
$html_encoding_label = 'Pagkokodigo ng panitik:';
$html_add = 'Idagdag';
$html_contacts = '%1$s Mga Kauugnayanin';
$html_modify = 'Baguhin';
$html_back = 'Bumalik';
$html_contact_add = 'Magdagdag ng bagong kaugnayan';
$html_contact_mod = 'Baguhin ang isang kaugnayan';
$html_contact_first = 'Unang pangalan';
$html_contact_last = 'Apelyido';
$html_contact_nick = 'Palayaw';
$html_contact_mail = 'E-liham';
$html_contact_list = 'Talaan ng kaugnayan ni %1$s';
$html_contact_del = 'mula sa talaan ng mga kaugnayan';
$html_contact_count = '%1$d Mga Kaugnayan';
$html_contact_err1 = 'Ang pinakamataas na bilang ng mga kaugnayan ay "%1$d"';
$html_contact_err2 = 'Hindi ka makapagdaragdag ng isang bagong kaugnayan';
$html_contact_err3 = 'Wala kang mga karapatan upang makapunta sa talaan ng mga kaugnayan';
$html_contact_none = 'Walang matagpuang mga kaugnayan.';
$html_del_msg = 'Burahin ang napiling mga mensahe?';
$html_down_mail = 'Ikargang pababa';
$original_msg = '-- Orihinal na Mensahe --';
$to_empty = 'Hindi dapat na walang lamang ang hanay ng \'Para kay\'!';
$html_images_warning = 'Para sa iyong kaligtasan, hindi ipinapakita ang malalayong mga larawan.';
$html_images_display = 'Ipakita ang mga larawan';
$html_smtp_error_no_conn = 'Hindi nagawang buksan ang ugnayang SMTP.';
$html_smtp_error_unexpected = 'Hindi inaasahang tugon ng SMTP:';
$lang_could_not_connect = 'Hindi makaugnay sa tagapaghain';
$lang_invalid_msg_num = 'Masamang bilang ng mensahe';
$html_file_upload_attack = 'Maaaring paglusob sa ikinakargang talaksan';
$html_invalid_email_address = 'Hindi tanggap na adres ng e-liham';
$html_invalid_msg_per_page = 'Hindi tanggap na bilang ng mga mensahe sa bawat isang pahina';
$html_invalid_wrap_msg = 'Hindi tanggap na lapad ng balot ng mensahe';
$html_seperate_msg_win = 'Mga mensaheng nasa loob ng nakahiwalay na bintana';
$html_err_file_contacts = 'Hindi nagawang buksan ang talaksan ng mga kaugnayan para sa pagsusulat.';
$html_session_file_error = 'Hindi nagawang buksan ang talaksan ng panahong inilaan para sa pagsusulat.';
$html_login_not_allowed = 'Hindi pinapahintulutan ang ganitong paglagdang papasok para sa pag-ugnay.';
$lang_err_send_delay = 'Dapat kang maghintay sa pagitan ng dalawang mga e-liham (%1$d mga segundo)';
$html_search = 'Hanapin';
